summaryrefslogtreecommitdiff
path: root/sc/source/ui/vba
diff options
context:
space:
mode:
authorEike Rathke <erack@redhat.com>2016-08-03 15:14:34 +0200
committerEike Rathke <erack@redhat.com>2016-08-03 15:16:50 +0200
commit4afd35f691ffbf369e90e031b17379f52a31c510 (patch)
tree4b09406762b7c2af31becbc4d77150ac2de0b562 /sc/source/ui/vba
parentf21a73bc5b1f13708e0f3ccd2c9d654c3ddc76be (diff)
use GRAM_API instead of GRAM_PODF_A1 in API context
... which right now is identical but may get corrections in future. Change-Id: Id4e1707afb32a3d8e073705072e5e65105f2a14a
Diffstat (limited to 'sc/source/ui/vba')
-rw-r--r--sc/source/ui/vba/vbarange.cxx8
1 files changed, 4 insertions, 4 deletions
diff --git a/sc/source/ui/vba/vbarange.cxx b/sc/source/ui/vba/vbarange.cxx
index 48524fde2599..1f7cec941937 100644
--- a/sc/source/ui/vba/vbarange.cxx
+++ b/sc/source/ui/vba/vbarange.cxx
@@ -875,11 +875,11 @@ protected:
double aDblValue = 0.0;
if ( aValue >>= sFormula )
{
// convert to GRAM_PODF_A1 style grammar because XCell::setFormula
// always compile it in that grammar. Perhaps
// css.sheet.FormulaParser should be used in future to directly
// pass formula tokens when that API stabilizes.
- if ( m_eGrammar != formula::FormulaGrammar::GRAM_PODF_A1 && ( sFormula.trim().startsWith("=") ) )
+ if ( m_eGrammar != formula::FormulaGrammar::GRAM_API && ( sFormula.trim().startsWith("=") ) )
{
uno::Reference< uno::XInterface > xIf( xCell, uno::UNO_QUERY_THROW );
ScCellRangesBase* pUnoRangesBase = dynamic_cast< ScCellRangesBase* >( xIf.get() );
@@ -891,7 +891,7 @@ protected:
// compile the string in the format passed in
std::unique_ptr<ScTokenArray> pArray(aCompiler.CompileString(sFormula));
// set desired convention to that of the document
- aCompiler.SetGrammar( formula::FormulaGrammar::GRAM_PODF_A1 );
+ aCompiler.SetGrammar( formula::FormulaGrammar::GRAM_API );
OUString sConverted;
aCompiler.CreateStringFromTokenArray(sConverted);
sFormula = EQUALS + sConverted;
@@ -2001,7 +2001,7 @@ ScVbaRange::setFormulaArray(const uno::Any& rFormula) throw (uno::RuntimeExcepti
ScTokenArray aTokenArray;
(void)ScTokenConversion::ConvertToTokenArray( getScDocument(), aTokenArray, aTokens );
- getScDocShell()->GetDocFunc().EnterMatrix( *getScRangeList()[0], nullptr, &aTokenArray, OUString(), true, true, EMPTY_OUSTRING, formula::FormulaGrammar::GRAM_PODF_A1 );
+ getScDocShell()->GetDocFunc().EnterMatrix( *getScRangeList()[0], nullptr, &aTokenArray, OUString(), true, true, EMPTY_OUSTRING, formula::FormulaGrammar::GRAM_API );
}
OUString
@@ -875,11 +875,11 @@ protected:
if ( aValue >>= sFormula )
{
- // convert to GRAM_PODF_A1 style grammar because XCell::setFormula
+ // convert to GRAM_API style grammar because XCell::setFormula
// always compile it in that grammar. Perhaps
// css.sheet.FormulaParser should be used in future to directly